{% extends 'admin/change_list.html' %}
{% block object-tools %}
    <div style="padding-bottom: 10px;">
        <form action="update-management/" method="POST">
            {% csrf_token %}

            <input type="number" name="group_id" value="1" min="1" style=" display: block;
         float: left;
         border-radius: 15px;
         ">

            <label style=" display: block;
         float: left;
         border-radius: 15px;
         padding-right: 10px;
         padding-left: 10px;">شماره گروه:</label>
            <br/><br/><br/><br/>
            <button class="object-tools .object-tools a:visited a:link" style=" display: block;
         float: left;
         border-radius: 15px;
         color: #fff;
         background: #999;
         padding-right: 10px;
         padding-left: 10px;
         font-weight: 400;
         font-size: 11px; font-size: 11px; line-height: 20px; list-style-type: square; font-family: 'IRANSans'; cursor: pointer; direction: rtl;"
                    type="submit">بروزرسانی مدیریت
            </button>
        </form>
    </div>
    <br/>
    {{ block.super }}
{% endblock %}
