# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-02-11 14:16


from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('aparnik_users', '0011_auto_20181202_1529'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, default=django.utils.timezone.now, verbose_name='Created at'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='user',
            name='update_at',
            field=models.DateTimeField(auto_now=True, verbose_name='Update at'),
        ),
    ]
