# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-11-02 19:21


from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('basemodels', '0003_basemodel_update_needed'),
        ('reviews', '0002_auto_20181025_1543'),
    ]

    operations = [
        migrations.CreateModel(
            name='ReviewSummary',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('rate', models.CharField(max_length=1, verbose_name='Rate')),
                ('count', models.BigIntegerField(default=0, verbose_name='Count')),
                ('model', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='review_summaries', to='basemodels.BaseModel', verbose_name='Models')),
            ],
            options={
                'verbose_name': 'Reivew Summary',
                'verbose_name_plural': 'Review Summary',
            },
        ),
    ]
