# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-05-11 12:36


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('filefields', '0009_auto_20190511_1212'),
    ]

    operations = [
        migrations.AddField(
            model_name='filefield',
            name='is_decrypt_needed',
            field=models.BooleanField(default=False, verbose_name='Is decrypt needed?'),
        ),
    ]
