@font-face {
    font-family: 'IRANSansWebFaNum';
    src: url('../font/IRANSansWeb(FaNum).woff') format('woff') ; /* IE6–8 */
}
@media only screen and (max-width: 764px) {
    .text_500{
        font-size: 10px !important;

    }  .text_404{
        font-size: 10px !important;

    }
}
@media only screen and (max-width: 414px) {

    .text_500{
        font-size: 10px !important;
    }
    .error{
        font-size: 10px;
    }
    .main h1 {
        font-size: 16px !important;
    }
    }
@media only screen and (max-width: 320px) {
    .text_500{
        font-size: 10px !important;


    }
    .text_404{
        font-size: 10px !important;

    }

}
body{
    background-color: #f8f9ff;
    color: #ffffff;
    font-family: 'IRANSansWebFaNum';
}
a{
    text-decoration: none;
    color: #ffffff;
}
.main{
    width: 50%;
    margin: 0 auto;
    /*padding-bottom: 43px;*/
    /*padding-top: 20px;*/
}
.btn{
    text-align: center;
    padding-top: 16px;
}
.btn a{
    padding: 5px 27px;
    background-color: #9b9b9b;
    color: #ffffff;
    font-family: 'IRANSansWebFaNum';
    width: 59px;
    border-radius: 21px;
    text-align: center;
    box-shadow: 0px 4px 11px #9b9b9b;
}
.text_404{
    text-align: center;
    color: #9b9b9b;
    direction: rtl;
    white-space: nowrap;
}
.text_500{
    text-align: center;
    color: #9b9b9b;

    white-space: nowrap;
}
.img_404{
    text-align: center;
}
.img_404 img{
    padding-top: 51px;
     width: 50%;
}
.img_500{
    text-align: center;
}
.img_500 img{
    padding-top: 51px;
    width: 50%;

}
/*Successful_payment*/
.main h3{
    color: black;
}
.btn_success{
    width: 160px;
    margin: 0 auto;
    padding-top: 16px;
}
.btn_success a{
    padding: 5px 27px;
    background-color: #89d3e9;
    color: #ffffff;
    font-family: 'IRANSansWebFaNum';
    width: 59px;
    border-radius: 21px;
    text-align: center;
    box-shadow: 0px 4px 11px #89d3e9;
}
.text_success span{
    color: #000;
    direction: rtl;
    text-align: center;
    white-space: nowrap;
}
.btn_success{
    text-align: center;
    color: #9b9b9b;
    direction: rtl;
    white-space: nowrap;
}
.main h1{
    color: black;
    text-align: center;
    white-space: nowrap;
}
.img_success {
   text-align: center;
}
.img_success img{
    width: 35%;
    padding-top: 23px;

}
.text_success{
    width: 100%;
    margin: 0 auto;
    text-align: center;
    white-space: nowrap;
}
.error{
    color: black;
    text-align: right;
}