# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-05-26 12:10


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aparnik_users', '0024_devicelogin_device_type'),
    ]

    operations = [
        migrations.AlterField(
            model_name='devicelogin',
            name='device_type_temp',
            field=models.CharField(blank=True, choices=[('a', 'Android'), ('i', 'iOS')], max_length=1, null=True, verbose_name='Device Type'),
        ),
    ]
