# Generated by Django 2.2 on 2019-06-15 14:30

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('notifications', '0005_notificationsystem'),
    ]

    operations = [
        migrations.AlterField(
            model_name='notification',
            name='from_user_obj',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='notificaiton_from_user', to=settings.AUTH_USER_MODEL, verbose_name='از کاربر'),
        ),
        migrations.AlterField(
            model_name='notification',
            name='type',
            field=models.CharField(choices=[('i', 'اطلاعات'), ('s', 'موفقیت'), ('w', 'هشدار'), ('e', 'خطا')], max_length=1, verbose_name='Type'),
        ),
    ]
