# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-12-05 11:07


from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('courses', '0009_auto_20181105_1424'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='basecourse',
            options={'verbose_name': '\\u062f\\u0648\\u0631\\u0647 \\u067e\\u0627\\u06cc\\u0647', 'verbose_name_plural': '\\u062f\\u0648\\u0631\\u0647 \\u0647\\u0627\\u06cc \\u067e\\u0627\\u06cc\\u0647'},
        ),
        migrations.AlterModelOptions(
            name='course',
            options={'verbose_name': '\\u062f\\u0648\\u0631\\u0647', 'verbose_name_plural': '\\u062f\\u0648\\u0631\\u0647 \\u0647\\u0627'},
        ),
    ]
