{% load i18n static %}<!doctype html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport"
          content="width=device-width, user-scalable=no, initial-scale=1.0, maximum-scale=1.0, minimum-scale=1.0">
    <meta http-equiv="X-UA-Compatible" content="ie=edge">
    <link rel="stylesheet" href="{% static "suit/css/style.css" %}">
    <title>500</title>
</head>
<body>
<div class="contaner">

    <div class="main">
        <div class="img_500">
            <img src="{% static "suit/img/500.png" %}">
        </div>
        <div style="text-align: center">
            <p class="text_500" >متاسفانه یک خطای غیر منظره رخ داده که خوشبختانه از طرف شما نیست<br> ما تمام تلاشمون رفع این مشکل میکنیم و ممنونیم که شما کنار ما هستید</p>

        </div>
        <div class="btn">
            <a href="/">منو از اینجا ببر</a>
        </div>

    </div>
</div>
</body>
</html>