# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-11-04 15:05


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('progresses', '0003_auto_20181103_2233'),
    ]

    operations = [
        migrations.AlterField(
            model_name='progresssummary',
            name='percentage',
            field=models.FloatField(verbose_name='Percentage'),
        ),
    ]
