# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-10-26 17:45


from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('questionanswers', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='qa',
            options={'verbose_name': '\\u067e\\u0631\\u0633\\u0634 \\u0648 \\u067e\\u0627\\u0633\\u062e', 'verbose_name_plural': '\\u067e\\u0631\\u0633\\u0634 \\u0648 \\u067e\\u0627\\u0633\\u062e \\u0647\\u0627'},
        ),
    ]
