# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-04-28 16:35


import ckeditor_uploader.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('courses', '0011_auto_20181214_1330'),
    ]

    operations = [
        migrations.AddField(
            model_name='basecourse',
            name='content',
            field=ckeditor_uploader.fields.RichTextUploadingField(blank=True, null=True, verbose_name='\\u0645\\u062d\\u062a\\u0648\\u0627'),
        ),
    ]
