# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-12-13 18:53


from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('segments', '0010_basesegment_pages'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='basesegment',
            name='sort',
        ),
    ]
