# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-11-13 18:48


from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('products', '0005_auto_20181108_1132'),
    ]

    operations = [
        migrations.RenameField(
            model_name='product',
            old_name='is_free',
            new_name='is_free_field',
        ),
    ]
