# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-05-26 10:43


from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('courses', '0018_remove_coursefile_time'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='coursesummary',
            options={'ordering': ('id',), 'verbose_name': '\\u062e\\u0644\\u0627\\u0635\\u0647 \\u062f\\u0648\\u0631\\u0647', 'verbose_name_plural': '\\u062e\\u0644\\u0627\\u0635\\u0647 \\u062f\\u0648\\u0631\\u0647'},
        ),
    ]
