# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-06-13 18:29


from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('questionanswers', '0005_auto_20190613_1815'),
        ('reviews', '0006_auto_20190613_1815'),
    ]

    operations = [
        migrations.AlterField(
            model_name='qa',
            name='model_obj2',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, related_name='question_answers_set', to='basemodels.BaseModel', verbose_name='\\u0686\\u0647 \\u0686\\u06cc\\u0632 \\u0631\\u0627 \\u0646\\u0645\\u0627\\u06cc\\u0634 \\u062f\\u0647\\u062f\\u061f'),
            preserve_default=False,
        ),
    ]
