# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-12-02 15:28


import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aparnik_users', '0009_user_co_sale_percentage_value'),
    ]

    operations = [
        migrations.AlterField(
            model_name='user',
            name='co_sale_percentage_value',
            field=models.IntegerField(default=-1, help_text='If the number is set to -1, then the value in the settings will apply', validators=[django.core.validators.MaxValueValidator(100), django.core.validators.MinValueValidator(-1)], verbose_name='Co Sale Percentage'),
        ),
        migrations.AlterField(
            model_name='user',
            name='limit_device_login',
            field=models.IntegerField(default=-1, help_text='If the number is set to -1, then the value in the settings will apply', verbose_name='Limit device login'),
        ),
    ]
