# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-10-26 17:45


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('segments', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='basesegment',
            options={'verbose_name': '\\u0628\\u062e\\u0634 \\u067e\\u0627\\u06cc\\u0647', 'verbose_name_plural': '\\u0628\\u062e\\u0634 \\u067e\\u0627\\u06cc\\u0647'},
        ),
        migrations.AlterField(
            model_name='basesegment',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, verbose_name='\\u0633\\u0627\\u062e\\u062a\\u0647 \\u0634\\u062f\\u0647 \\u062f\\u0631'),
        ),
        migrations.AlterField(
            model_name='basesegment',
            name='is_active',
            field=models.BooleanField(default=True, verbose_name='\\u0641\\u0639\\u0627\\u0644\\u061f'),
        ),
        migrations.AlterField(
            model_name='basesegment',
            name='model_obj',
            field=models.ManyToManyField(to='basemodels.BaseModel', verbose_name='\\u0686\\u0647 \\u0686\\u06cc\\u0632 \\u0631\\u0627 \\u0646\\u0645\\u0627\\u06cc\\u0634 \\u062f\\u0647\\u062f\\u061f'),
        ),
        migrations.AlterField(
            model_name='basesegment',
            name='pages',
            field=models.ManyToManyField(blank=True, related_name='segment_pages', to='pages.Page', verbose_name='\\u0635\\u0641\\u062d\\u0647'),
        ),
        migrations.AlterField(
            model_name='basesegment',
            name='sort',
            field=models.IntegerField(default=0, verbose_name='\\u0645\\u0631\\u062a\\u0628 \\u0633\\u0627\\u0632\\u06cc'),
        ),
        migrations.AlterField(
            model_name='basesegment',
            name='title',
            field=models.CharField(max_length=60, verbose_name='\\u0639\\u0646\\u0648\\u0627\\u0646'),
        ),
        migrations.AlterField(
            model_name='basesegment',
            name='update_at',
            field=models.DateTimeField(auto_now=True, verbose_name='\\u0628\\u0631\\u0648\\u0632\\u0631\\u0633\\u0627\\u0646\\u06cc \\u0634\\u062f\\u0647 \\u062f\\u0631'),
        ),
    ]
