# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-12-10 15:11


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('news', '0004_auto_20181210_1509'),
    ]

    operations = [
        migrations.AlterField(
            model_name='news',
            name='cover_images',
            field=models.ManyToManyField(blank=True, to='filefields.FileField', verbose_name='Cover Images'),
        ),
    ]
